#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


# This is a part of VHFFS platform

# This file is used to generate the admin part of the menu (left in the panel)

package Vhffs::Panel::Admin;

use DBI;
use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;
use Vhffs::User;
use Vhffs::Main;
use Vhffs::Acl;
use Vhffs::Services::Cvs;
use Vhffs::Panel::Main;
use Vhffs::Constants;


sub menu
{
	my ($class ,  $data ) = @_;

	my $vhffs = $data->{'vhffs'};
	my $session = $data->{'session'};
	my $user = $data->{'user'};
	my $group = $data->{'group'};
	my $cgi = $data->{'cgi'};

	my $templatesdir = $vhffs->get_config->get_templatedir;

	my $template = new HTML::Template( filename => "$templatesdir/admin/main/main.tmpl" );
	$template->param( MENU_TITLE => gettext( "Administrator Menu" ) );
	$template->param( SHOW_HIDE => gettext( "Show/Hide" ) );
	my $subtemplate;

	#Print the General Admin/Modo Panel
	if( $user->is_admin == 1 )
	{
		$subtemplate = new HTML::Template( filename => "$templatesdir/admin/main/general.tmpl" );
	}
	else
	{
		$subtemplate = new HTML::Template( filename => "$templatesdir/admin/main/general-modo.tmpl" );
	}


	$subtemplate->param( TEXT_ADMIN_GENERAL => gettext( "General" ) ); 
	$subtemplate->param( TEXT_STATS => gettext( "Get Statistics" ) ); 
	$subtemplate->param( TEXT_MODERATION => gettext( "Moderation" ) );

	if( $user->is_admin == 1 )   {
		$subtemplate->param( TEXT_VHFFSSU => gettext( "Change user-id" ) );
		$subtemplate->param( TEXT_MAILING => gettext( "Mail to all hosted people" ) );
		$subtemplate->param( TEXT_AMAILING => gettext( "Manage mailings" ) );
		$subtemplate->param( TEXT_OBJECT_LIST => gettext( "List all objects" ) );
		$subtemplate->param( TEXT_OBJECT_SEARCH => gettext( "Search for an object" ) );			           

	}

	$template->param( ADMIN_GENERAL => $subtemplate->output );


	$subtemplate = new HTML::Template( filename => "$templatesdir/admin/user/menu.tmpl" );
	$subtemplate->param( TEXT_ADMIN_USER => gettext( "User Admin" ) ); 
	$subtemplate->param( TEXT_LIST_USER => gettext( "List all users" ) ); 
	$subtemplate->param( TEXT_SEARCH_USER => gettext( "Search for an user" ) );
					           
	$template->param( ADMIN_USERS => $subtemplate->output );


	$subtemplate = new HTML::Template( filename => "$templatesdir/admin/group/menu.tmpl" );
	$subtemplate->param( TEXT_ADMIN_GROUP => gettext( "Group Admin" ) ); 
	$subtemplate->param( TEXT_LIST_GROUP => gettext( "List all groups" ) ); 
	$subtemplate->param( TEXT_SEARCH_GROUP => gettext( "Search for a group" ) );
					           
	$template->param( ADMIN_GROUPS => $subtemplate->output );


	if( $vhffs->get_config->use_web == 1 )
	{
		$subtemplate = new HTML::Template( filename => "$templatesdir/admin/web/menu.tmpl" );
		$subtemplate->param( TEXT_ADMIN_WEB => gettext( "Web Admin" ) );
		$subtemplate->param( TEXT_LIST_WEB => gettext( "List websites" ) );
		$subtemplate->param( TEXT_SEARCH_WEB => gettext( "Search for a website" ) );

		$template->param( ADMIN_WEB => $subtemplate->output );
	}
	else
	{
		$template->param( ADMIN_WEB => "" );
	}

	if( $vhffs->get_config->use_svn == 1 )
	{
		$subtemplate = new HTML::Template( filename => "$templatesdir/admin/svn/menu.tmpl" );
		$subtemplate->param( TEXT_ADMIN_SVN => gettext( "Subversion Admin" ) );
		$subtemplate->param( TEXT_LIST_SVN => gettext( "List all SVN repo" ) );
		$subtemplate->param( TEXT_SEARCH_SVN => gettext( "Search for a SVN repository" ) );
		$template->param( ADMIN_SVN => $subtemplate->output );
	}
	else
	{
		$template->param( ADMIN_SVN => "" );
	}


	if( $vhffs->get_config->use_cvs == 1 )
	{
		$subtemplate = new HTML::Template( filename => "$templatesdir/admin/cvs/menu.tmpl" );
		$subtemplate->param( TEXT_ADMIN_CVS => gettext( "CVS Admin" ) );
		$subtemplate->param( TEXT_LIST_CVS => gettext( "List all CVS" ) );
		$subtemplate->param( TEXT_SEARCH_CVS => gettext( "CVS Search" ) );
		$template->param( ADMIN_CVS => $subtemplate->output );
	}
	else
	{
		$template->param( ADMIN_CVS => "" );
	}

    if( $vhffs->get_config->use_mysql == 1 )
    {
        $subtemplate = new HTML::Template( filename => "$templatesdir/admin/mysql/menu.tmpl" );
        $subtemplate->param( TEXT_ADMIN_MYSQL => gettext( "MYSQL Admin" ) );
        $subtemplate->param( TEXT_LIST_MYSQL => gettext( "List all DBs" ) );
        $subtemplate->param( TEXT_SEARCH_MYSQL => gettext( "DB Search" ) );
        $template->param( ADMIN_MYSQL => $subtemplate->output );
    }
    else
    {
        $template->param( ADMIN_MYSQL => "" );
    }


    if( $vhffs->get_config->use_mail == 1 )
    {
        $subtemplate = new HTML::Template( filename => "$templatesdir/admin/mail/menu.tmpl" );
        $subtemplate->param( TEXT_ADMIN_MAIL => gettext( "Mail Admin" ) );
        $subtemplate->param( TEXT_LIST_MAIL => gettext( "List all domain names" ) );
        $subtemplate->param( TEXT_SEARCH_MAIL => gettext( "Search for a mail domain" ) );
        $template->param( ADMIN_MAIL  => $subtemplate->output );
    }
    else
    {
        $template->param( ADMIN_MAIL => "" );
    }

    if( $vhffs->get_config->use_mailling == 1 )
    {
        $subtemplate = new HTML::Template( filename => "$templatesdir/admin/mailing/menu.tmpl" );
        $subtemplate->param( TEXT_ADMIN_MAILLING => gettext( "Mailing-lists Admin" ) );
        $subtemplate->param( TEXT_LIST_MAILLING => gettext( "List all lists" ) );
        $subtemplate->param( TEXT_SEARCH_MAILLING => gettext( "Search for a list" ) );
        $template->param( ADMIN_MAILLINGLIST => $subtemplate->output );
    }
    else
    {
        $template->param( ADMIN_MAILLINGLIST => "" );
    }

    if( $vhffs->get_config->use_postgres == 1 )
    {
        $subtemplate = new HTML::Template( filename => "$templatesdir/admin/pgsql/menu.tmpl" );
        $subtemplate->param( TEXT_ADMIN_POSTGRES => gettext( "Postgres Admin" ) );
        $subtemplate->param( TEXT_LIST_POSTGRES => gettext( "List all Postgres DB" ) );
        $subtemplate->param( TEXT_SEARCH_POSTGRES => gettext( "Search for a PostgreSQL database" ) );
        $template->param( ADMIN_POSTGRESQL  => $subtemplate->output );
    }
    else
    {
        $template->param( ADMIN_POSTGRESQL => "" );
    }

    if( $vhffs->get_config->use_dns == 1 )
    {
        $subtemplate = new HTML::Template( filename => "$templatesdir/admin/dns/menu.tmpl" );
        $subtemplate->param( TEXT_ADMIN_DNS => gettext( "NS Admin" ) );
        $subtemplate->param( TEXT_LIST_DNS => gettext( "List all domains" ) );
        $subtemplate->param( TEXT_SEARCH_DNS => gettext( "Search for a domain" ) );
        $template->param( ADMIN_DNS  => $subtemplate->output );
    }
    else
    {
        $template->param( ADMIN_DNS => "" );
    }

    if( $vhffs->get_config->use_largefile == 1 )
    {
        $subtemplate = new HTML::Template( filename => "$templatesdir/admin/largefile/menu.tmpl" );
        $subtemplate->param( TEXT_ADMIN_LARGEFILE => gettext( "Hosted files admin" ) );
        $subtemplate->param( TEXT_LIST_LARGEFILE => gettext( "List all hosted files" ) );
        $subtemplate->param( TEXT_SEARCH_LARGEFILE => gettext( "Search for a file" ) );
        $template->param( ADMIN_LARGEFILE  => $subtemplate->output );
    }
    else
    {
        $template->param( ADMIN_LARGEFILE => "" );
    }

    if( $vhffs->get_config->use_repository == 1 )
    {
        $subtemplate = new HTML::Template( filename => "$templatesdir/admin/repository/menu.tmpl" );
        $subtemplate->param( TEXT_ADMIN_REPOSITORY => gettext( "Download repository admin" ) );
        $subtemplate->param( TEXT_LIST_REPOSITORY => gettext( "List all download repositories" ) );
        $subtemplate->param( TEXT_SEARCH_REPOSITORY => gettext( "Search for a download repository" ) );
        $template->param( ADMIN_REPOSITORY  => $subtemplate->output );
    }
    else
    {
        $template->param( ADMIN_REPOSITORY => "" );
    }

	return $template->output;
}

1;
