#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


package Vhffs::Panel::Mailinglist;

use DBI;
use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;
use Vhffs::User;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Services::Mailing;



sub getall_list_to_moderate
{
    my( $main , $query , $request);
    $main = shift;
    $query = "SELECT l.ml_id , l.local_part , l.domain, o.description ,  u.username , g.groupname , o.object_id FROM vhffs_ml l, vhffs_object o , vhffs_users u , vhffs_groups g  WHERE u.uid=l.owner_uid AND g.gid=l.owner_gid AND l.object_id=o.object_id AND o.state='".Vhffs::Constants::WAITING_FOR_VALIDATION."'";
    $request = $main->{'db'}->{'DB_READ'}->prepare( $query );

    return undef if ( $request->execute <= 0 );
    return( $request->fetchall_hashref('ml_id') );
}


sub getall_list_per_group
{
    my $group  = shift;
    my $main  = shift ;
    my $state = shift;

    return undef if ( $group->fetch < 0 );

    my $query;

    if( defined $state )
    {
        $query = "SELECT l.ml_id, l.local_part, l.domain, l.object_id, o.state  FROM vhffs_ml l, vhffs_object o WHERE o.object_id=l.object_id AND o.state='".$state."' AND l.owner_gid='".$group->get_gid."'";
    }
    else
    {
        $query = "SELECT l.ml_id, l.local_part , l.domain, l.object_id, o.state  FROM vhffs_ml l, vhffs_object o WHERE o.object_id=l.object_id AND l.owner_gid='".$group->get_gid."'";
    }

    my $request = $main->{'db'}->{'DB_READ'}->prepare( $query ) or return -1;

    return undef if ( $request->execute() <= 0);

    return( $request->fetchall_hashref('ml_id') );
}


sub create_list
{
    my $main = shift;
    my $lpart = shift;
    my $domain = shift;
    my $user = shift;
    my $group = shift;
    
    return -5 if( $user->fetch < 0 );
    return -5 if( $group->fetch < 0 ); 
    
    my $list = new Vhffs::Services::Mailing( $main , $lpart , $domain );
    return -1 if( ! defined $list );
    $list->set_user( $user );
    $list->set_group( $group );
    $list->set_admin( $user->get_mail );
    
    return -1 if ( $list->create < 0 );
    
    return -2 if ( Vhffs::Acl::add_acl( $user , $list , Vhffs::Constants::ACL_DELETE , $main ) < 0 );
    return -3 if( Vhffs::Acl::add_acl( $group , $list , Vhffs::Constants::ACL_VIEW , $main ) < 0 ); 
    
    return 1;
}



sub menu
{
	my ( $class , $data ) = @_;

	my $vhffs = $data->{'vhffs'};
	my $session = $data->{'session'};
	my $user = $data->{'user'};
	my $group = $data->{'group'};
	my $cgi = $data->{'cgi'};

	my $templatesdir = $vhffs->get_config->get_templatedir;
	my $template = new HTML::Template( filename => "$templatesdir/mailinglist/menu.tmpl" );
	$template->param( TEXT_CREATE => gettext("Create") );
	$template->param( TEXT_MAILINGLIST => gettext("Mailing List") );

	my $subtemplate;

	my $mls = Vhffs::Services::Mailing::getall( $vhffs , undef , undef , $group );
	my $ml;
	my $output = "";
	if( defined $mls )
	{
		foreach $ml ( @{$mls} )
		{
			if( $ml->get_status == Vhffs::Constants::ACTIVATED )
			{
				$subtemplate = new HTML::Template( filename => "$templatesdir/mailinglist/menu_sub.tmpl" );
				$subtemplate->param( NAME => $ml->get_localpart . "\@" . $ml->get_domain);
				$subtemplate->param( LOCAL => $ml->get_localpart );
				$subtemplate->param( DOMAIN => $ml->get_domain );
	            $subtemplate->param( HISTORY => gettext("History"));
	            $subtemplate->param( OID => $ml->get_oid );
			}
			else
			{
				$subtemplate = new HTML::Template( filename => "$templatesdir/mailinglist/menu_sub_wait.tmpl" );
				$subtemplate->param( NAME => $ml->get_localpart . "\@" . $ml->get_domain);
	            $subtemplate->param( HISTORY => gettext("History"));
	            $subtemplate->param( REASON => Vhffs::Functions::status_string_from_status_id( $ml->get_status ));
	            $subtemplate->param( OID => $ml->get_oid );
			}


			$output .= $subtemplate->output if( defined $subtemplate );
			undef( $subtemplate );
		}
	}

	$template->param( SUB_MAILINGLIST => $output );

	return $template->output;
}



1;
