#!/usr/bin/perl -w

package Vhffs::Panel::Main;
require Exporter;
@ISA    = qw(Exporter);
@EXPORT = qw( open_template display display_light );

use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use Vhffs::Main;
use Vhffs::User;
use Vhffs::Group;
use Vhffs::Panel::Menu;
use Vhffs::Panel::User;


sub check
{
	my $vhffs = shift;
	my $templatedir = $vhffs->get_config->get_templatedir;
	my $template;	


	if( $vhffs->is_valid() == 0 )
	{   
		$template = new HTML::Template( filename => $templatedir."/main/close.tmpl" );
		$template->param( TITLE         => gettext("Platform temporary closed") );
		$template->param( TEXT_CLOSE    => gettext("Platform temporary closed<br/>database error") );
		$template->param( TEXT_EXPLAIN  => gettext("This platform is temporary closed. Administrators are performing some maintenances tasks or system has database errors. Please come back in a few minutes to log in.") );
    
		display_light Vhffs::Panel::Main( $template );
		exit( 0 );
	}

	if( $vhffs->get_config->get_panel_open != 1 )
	{
		$template = new HTML::Template( filename => $templatedir."/main/close.tmpl" );
		$template->param( TITLE         => gettext("Platform temporary closed") );
		$template->param( TEXT_CLOSE    => gettext("Platform temporary closed.") );
		$template->param( TEXT_EXPLAIN  => gettext("This platform is temporary closed. Administrators are performing some maintenances tasks. Please come back in a few minutes to log in.") );
    
		display_light Vhffs::Panel::Main( $template );
		exit( 0 );
	}
}


sub get_theme
{
	my $vhffs = shift;
	my $theme = CGI->cookie( "theme" );

	$theme = $vhffs->get_config->get_default_theme() if ( ! defined $theme );

	my $themetestfile = $vhffs->get_config->get_themesdir . "/" . $theme . "/main.css";
	return $theme if ( -f $themetestfile );

	$themetestfile = $vhffs->get_config->get_themesdir . "/vhffs/main.css";
	return "vhffs" if ( -f $themetestfile );
	
	return undef;
}


sub select_lang
{
	use Vhffs::Intl;
	my $main = shift;
	my $txt = "";
	my $langs = Vhffs::Intl::get_languages( $main );
	my $l;
	foreach $l ( @{$langs} )
	{
		$txt .= "<a href=\"auth.pl?lang=".$l."\"><img src=\"/themes/".get_theme( $main )."/images/".$l.".png\" alt=\"".$l."language\"/></a>";
	}
	return $txt;
}

sub cookie_lang
{
	use CGI;
	my $vhffs;
	my $cgi;
	my $cookie;
	my $lang;

	$vhffs = shift;
	$cgi = new CGI;

	$lang = $cgi->param( "lang" );
	$cookie = CGI->cookie( "language" => $lang ) if ( defined $lang );
	$lang = CGI->cookie( "language" ) if ( ! defined $lang );
	$lang = $vhffs->get_config->get_default_language() if ( ! defined $lang );
	$lang = "en_US" if ( ! defined $lang );

	setlocale(LC_ALL, $lang );
	bindtextdomain("vhffs", $vhffs->get_config->get_intldir);
	textdomain("vhffs");

	return $cookie;
}

sub new
{
	my $bad_news;
	my $session;
	my $user;
	my $username;
	my $uid;

	# get current cgi
	my $cgi = new CGI;

	# Init the Vhffs Main System
	my $vhffs = init Vhffs::Main;
	my $config = $vhffs->get_config;
	my $templatedir = $vhffs->get_config->get_templatedir;

	# fetch the cookie which contain the sessions ID and the session
	my $sid = CGI->cookie("session");
	if( ! defined $sid )
	{
		$bad_news = gettext("No cookie found, please accept the cookie and then please login again !");
	}

	if( ! defined $bad_news )
	{
		$session = new CGI::Session(undef, $sid, {Directory=>'/tmp'});
		$username = $session->param("username");
		$uid = $session->param("uid");

		if(!$username || !$uid || $session->id() ne $sid)  {
			$bad_news = gettext("Expired session ! Please login again");
			$session->delete();
		}
	}

	if( ! defined $bad_news )
	{
		$user = new Vhffs::User( $vhffs , $username , '401' );
	
		#Try to verify if the user exist and is allowed to browse panel
		#Then, set some preferences
		if( ! defined $user || $user->fetch < 0 )
		{
			$bad_news = gettext("User does not exist");
		}
		elsif( $user->get_status != Vhffs::Constants::ACTIVATED )
		{
			$bad_news = gettext("You're are not allowed to browse panel");
		}
		else
		{
			cookie_lang( $vhffs );
		}
	}

	if( defined $bad_news )
	{
		my $template = new HTML::Template( filename => $templatedir."/main/login_failed.tmpl" );
		$template->param( TEXT_LOGINFAILED => $bad_news);
		$template->param( TEXT_LOGIN => gettext("Login") );
		$template->param( THEME => get_theme( $vhffs ) );
		print "Content-type: text/html\n\n" , $template->output;
		return 0;
	}


	my $projectname = $cgi->param("project");
	$session->param("project", $projectname) if( defined $projectname );

	my $group;
	$projectname = $session->param("project");
	if( defined $projectname )  {
		$group = new Vhffs::Group( $vhffs , $projectname , '401' );
		if( $group->fetch < 0  ||  $group->get_status != Vhffs::Constants::ACTIVATED  ||  $group->is_user_in_group( $user ) != 1  )
		{
			$session->param("project", NULL);
			undef $group;
		}
	}

	my $maintemplate = new HTML::Template( filename => $templatedir."/main/panel.tmpl" );
	$maintemplate->param( PANEL_TITLE => gettext("VHFFS Panel") );

	my $theme = get_theme( $vhffs );
	$maintemplate->param( THEME => $theme );


	my $data = {};
	$data->{'vhffs'} = $vhffs;
	$data->{'session'} = $session;
	$data->{'template'} = $maintemplate;
	$data->{'templatedir'} = $templatedir;
	$data->{'user'} = $user;
	$data->{'cgi'} = $cgi;
	$data->{'config'} = $config;
	$data->{'theme'} = $theme;
	if( defined $group )  {
		$data->{'group'} = $group;
		$data->{'groupname'} = $projectname;
	}

	my $menutemplate = new Vhffs::Panel::Menu($data);
	$maintemplate->param( MENU => $menutemplate->output );

	return $data;
}

sub right_first
{
	my ( $class , $vhffs , $session , $user ) = @_;

	my $templatedir = $vhffs->get_config->get_templatedir;
	my $template = new HTML::Template( filename => $templatedir."/misc/welcome.tmpl" );

	$template->param( TEXT_WELCOME => gettext("Welcome") );
	$template->param( USERNAME => $user->get_username() );

	return $template;
}

sub project_info
{
	my ( $class , $vhffs , $session , $user ) = @_;

	my $projectname = $session->param("project");
	my $temp;
	my $object;
	my $objects;
	my $group;
	my $template;
	my $templatedir;
	my $subtemplate;

	$templatedir = $vhffs->get_config->get_templatedir;
		
	$group = new Vhffs::Group( $vhffs , $projectname , '401' );
	if( ( ! defined( $group ) ) || ( $group->fetch <= 0 ) )
	{
		$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
		$template->param( MESSAGE  => gettext("Group error" ) );
	}
	else
	{
	$template = new HTML::Template( filename => $templatedir."/group/info.tmpl" );
	$template->param( TEXT_TITLE => sprintf( gettext("Group %s") , $projectname ));
	
	$template->param( GROUPNAME => $group->get_groupname );
	$template->param( QUOTA_VALUE => sprintf( gettext("Quota (used/total) : %s/%s") , $group->get_quota_used , $group->get_quota ) );
	
	if( $vhffs->get_config->use_web == 1 )
	{
		$temp = "";
		$template->param( WEBAREA => gettext("Webarea for this group") );
		$objects = Vhffs::Services::Httpd::getall( $vhffs , undef , undef , $group );
		if( defined $objects )
		{	
			foreach $object ( @{$objects} )
			{
				$subtemplate = new HTML::Template( filename => $templatedir."/misc/group_service.tmpl" );
				$subtemplate->param( SERVICE  => "web" );
				$subtemplate->param( VALUE  => $object->get_servername );
				$subtemplate->param( TEXT  => gettext("Go to admin") );
				$subtemplate->param( HISTORY  => gettext("View history") );
				$subtemplate->param( OID  => $object->get_oid );
				$temp .= $subtemplate->output;
			}
		}
		else
		{
			$temp = gettext("No webarea for this group");
		}
		$template->param( WEBAREA_VALUES => $temp );
	}
	if( $vhffs->get_config->use_mysql == 1 )
	{
		$temp = "";
		$template->param( MYSQL => gettext("Mysql database for this group") );
		$objects = Vhffs::Services::Mysql::getall( $vhffs , undef , undef , $group );
		if( defined $objects )
		{	
			foreach $object ( @{$objects} )
			{
				$subtemplate = new HTML::Template( filename => $templatedir."/misc/group_service.tmpl" );
				$subtemplate->param( SERVICE  => "mysql" );
				$subtemplate->param( VALUE  => $object->get_dbname );
				$subtemplate->param( TEXT  => gettext("Go to admin") );
				$subtemplate->param( HISTORY  => gettext("View history") );
				$subtemplate->param( OID  => $object->get_oid );
				$temp .= $subtemplate->output;
			}
		}
		else
		{
			$temp = gettext("No mysql database for this group");
		}
		$template->param( MYSQL_VALUES => $temp );
	}


	if( $vhffs->get_config->use_postgres == 1 )
	{
		$temp = "";
		$template->param( PGSQL => gettext("PostgreSQL database for this group") );
		$objects = Vhffs::Services::Postgres::getall( $vhffs , undef , undef , $group );
		if( defined $objects )
		{	
			foreach $object ( @{$objects} )
			{
				$subtemplate = new HTML::Template( filename => $templatedir."/misc/group_service.tmpl" );
				$subtemplate->param( SERVICE  => "pgsql" );
				$subtemplate->param( VALUE  => $object->get_dbname );
				$subtemplate->param( TEXT  => gettext("Go to admin") );
				$subtemplate->param( HISTORY  => gettext("View history") );
				$subtemplate->param( OID  => $object->get_oid );
				$temp .= $subtemplate->output;
			}
		}
		else
		{
			$temp = gettext("No PostgreSQL database for this group");
		}
		$template->param( PGSQL_VALUES => $temp );
	}


	if( $vhffs->get_config->use_cvs == 1 )
	{
		$temp = "";
		$template->param( CVS => gettext("CVS repositories for this group") );
		$objects = Vhffs::Services::Cvs::getall( $vhffs , undef , undef , $group );
		if( defined $objects )
		{	
			foreach $object ( @{$objects} )
			{
				$subtemplate = new HTML::Template( filename => $templatedir."/misc/group_service.tmpl" );
				$subtemplate->param( SERVICE  => "cvs" );
				$subtemplate->param( VALUE  => $object->get_cvsroot );
				$subtemplate->param( TEXT  => gettext("Go to admin") );
				$subtemplate->param( HISTORY  => gettext("View history") );
				$subtemplate->param( OID  => $object->get_oid );
				$temp .= $subtemplate->output;
			}
		}
		else
		{
			$temp = gettext("No CVS repository for this group");
		}
		$template->param( CVS_VALUES => $temp );
	}


	if( $vhffs->get_config->use_svn == 1 )
	{
		$temp = "";
		$template->param( SVN => gettext("SVN repositories for this group") );
		$objects = Vhffs::Services::Svn::getall( $vhffs , undef , undef , $group );
		if( defined $objects )
		{	
			foreach $object ( @{$objects} )
			{
				$subtemplate = new HTML::Template( filename => $templatedir."/misc/group_service.tmpl" );
				$subtemplate->param( SERVICE  => "svn" );
				$subtemplate->param( VALUE  => $object->get_title );
				$subtemplate->param( TEXT  => gettext("Go to admin") );
				$subtemplate->param( HISTORY  => gettext("View history") );
				$subtemplate->param( OID  => $object->get_oid );
				$temp .= $subtemplate->output;
			}
		}
		else
		{
			$temp = gettext("No SVN repository for this group");
		}
		$template->param( SVN_VALUES => $temp );
	}



	if( $vhffs->get_config->use_mailing == 1 )
	{
		$temp = "";
		$template->param( MLS => gettext("Mailing-lists for this group") );
		$objects = Vhffs::Services::Mailing::getall( $vhffs , undef , undef , $group );
		if( defined $objects )
		{	
			foreach $object ( @{$objects} )
			{
				$subtemplate = new HTML::Template( filename => $templatedir."/misc/group_service.tmpl" );
				$subtemplate->param( SERVICE  => "mailinglist" );
				$subtemplate->param( VALUE  => $object->get_listname );
				$subtemplate->param( TEXT  => gettext("Go to admin") );
				$subtemplate->param( HISTORY  => gettext("View history") );
				$subtemplate->param( OID  => $object->get_oid );
				$temp .= $subtemplate->output;
			}
		}
		else
		{
			$temp = gettext("No Mailing-list for this group");
		}
		$template->param( MLS_VALUES => $temp );
	}


	if( $vhffs->get_config->use_mail == 1 )
	{
		$temp = "";
		$template->param( MAILS => gettext("Mail domain for this group") );
		$objects = Vhffs::Services::Mail::getall( $vhffs , undef , undef , $group );
		if( defined $objects )
		{	
			foreach $object ( @{$objects} )
			{
				$subtemplate = new HTML::Template( filename => $templatedir."/misc/group_service.tmpl" );
				$subtemplate->param( SERVICE  => "mail" );
				$subtemplate->param( VALUE  => $object->get_domain );
				$subtemplate->param( TEXT  => gettext("Go to admin") );
				$subtemplate->param( HISTORY  => gettext("View history") );
				$subtemplate->param( OID  => $object->get_oid );
				$temp .= $subtemplate->output;
			}
		}
		else
		{
			$temp = gettext("No Mail domain for this group");
		}
		$template->param( MAILS_VALUES => $temp );
	}


	if( $vhffs->get_config->use_largefile == 1 )
	{
		use Vhffs::Services::LargeFile;
		$temp = "";
		$template->param( LARGEFILE => gettext("Hosted files for this group") );
		$objects = Vhffs::Services::LargeFile::getall( $vhffs , undef , undef , $group );
		if( defined $objects )
		{	
			foreach $object ( @{$objects} )
			{
				$subtemplate = new HTML::Template( filename => $templatedir."/misc/group_service.tmpl" );
				$subtemplate->param( SERVICE  => "largefile" );
				$subtemplate->param( VALUE  => $object->get_filename );
				$subtemplate->param( TEXT  => gettext("Go to admin") );
				$subtemplate->param( HISTORY  => gettext("View history") );
				$subtemplate->param( OID  => $object->get_oid );
				$temp .= $subtemplate->output;
			}
		}
		else
		{
			$temp = gettext("No hosted files for this group");
		}
		$template->param( LARGEFILE_VALUES => $temp );
	}

	if( $vhffs->get_config->use_dns == 1 )
	{
		$temp = "";
		$template->param( REPOSITORY => gettext("Download repositories for this group") );
		$objects = Vhffs::Services::Repository::getall( $vhffs , undef , undef , $group );
		if( defined $objects )
		{	
			foreach $object ( @{$objects} )
			{
				$subtemplate = new HTML::Template( filename => $templatedir."/misc/group_service.tmpl" );
				$subtemplate->param( SERVICE  => "repository" );
				$subtemplate->param( VALUE  => $object->get_name );
				$subtemplate->param( TEXT  => gettext("Go to admin") );
				$subtemplate->param( HISTORY  => gettext("View history") );
				$subtemplate->param( OID  => $object->get_oid );
				$temp .= $subtemplate->output;
			}
		}
		else
		{
			$temp = gettext("No download repository for this group");
		}
		$template->param( REPOSITORY_VALUES => $temp );
	}

	if( $vhffs->get_config->use_repository == 1 )
	{
		$temp = "";
		$template->param( DNS => gettext("Domains for this group") );
		$objects = Vhffs::Services::DNS::getall( $vhffs , undef , undef , $group );
		if( defined $objects )
		{	
			foreach $object ( @{$objects} )
			{
				$subtemplate = new HTML::Template( filename => $templatedir."/misc/group_service.tmpl" );
				$subtemplate->param( SERVICE  => "dns" );
				$subtemplate->param( VALUE  => $object->get_domain );
				$subtemplate->param( TEXT  => gettext("Go to admin") );
				$subtemplate->param( HISTORY  => gettext("View history") );
				$subtemplate->param( OID  => $object->get_oid );
				$temp .= $subtemplate->output;
			}
		}
		else
		{
			$temp = gettext("No DNS domain for this group");
		}
		$template->param( DNS_VALUES => $temp );
	}
	


	}
	return $template;
}


sub set_refresh_url
{
	my ( $class , $panel , $url , $time ) = @_;

	my $maintemplate = $panel->{'template'};
	$time = 3 if( $time == 0 );
	$maintemplate->param( HEADERS_SUP => "<meta http-equiv=\"refresh\" content=\"$time; url=$url\">" );
	return;
}


sub display
{
	my ( $class , $panel , $content, $cookie, $cookie2 ) = @_;

	if( ref( $class ) eq 'HASH' )
	{
		$cookie2 = $cookie;
		$cookie = $content;
		$content = $panel;
		$panel = $class;
	}

	my $maintemplate = $panel->{'template'};
	$maintemplate->param( CENTRE => $content );

	if( defined $panel->{'group'} )
	{
		$maintemplate->param( GROUPNAME => sprintf( gettext( "Current group: %s" ) , $panel->{'group'}->get_groupname )  );
	}

	if( ! defined $cookie )
	{
		print CGI->header( -type=>"text/html", -charset=>"utf-8" );
	}
	else
	{
		if( ! defined $cookie2)
		{
			print CGI->header( -cookie=>$cookie, -type=>"text/html", -charset=>"utf-8" );
		}
		else
		{
			print CGI->header( -cookie=>[$cookie,$cookie2], -type=>"text/html", -charset=>"utf-8" );
		}
	}

	print $maintemplate->output;

	return;
}


sub display_light
{
	my ( $class , $vhffs, $template, $cookie ) = @_;

	if( ! $cookie )
	{
		print CGI->header( -type=>"text/html", -charset=>"utf-8" );
	}
	else
	{
		print CGI->header( -cookie=>$cookie, -type=>"text/html", -charset=>"utf-8" );
	}

	my $theme = get_theme( $vhffs );
	$template->param( THEME => $theme );

	print $template->output;

	return;
}



sub list_themes
{
	my $vhffs = shift;
	return -1 if( ! defined $vhffs );

	my @themes;
	
	my $dir = $vhffs->get_config->get_themesdir;

	return undef if( ! ( defined $dir ) );

	opendir( DIR , $dir) or return -2;
	
	my @files = readdir( DIR );

	foreach( @files )
	{
		next if( /\./);
		if( -d $dir."/".$_ )
		{
			push @themes , $_;
		}
	}

	closedir( DIR );

	return @themes;
}


sub list_languages
{
	my $vhffs = shift;
	return -1 if( ! defined $vhffs );

	my @langs;
	
	my $dir = $vhffs->get_config->get_intldir;
	return undef if( ! ( defined $dir ) );

#	push @langs , "en_US";

	opendir( DIR , $dir) or return @langs;
	my @files = readdir( DIR );
	foreach( @files )
	{
		next if( /\./);
		if( -d $dir."/".$_ )
		{
			push @langs , $_;
		}
	}
	closedir( DIR );

	return @langs;
}


sub open_template
{
	my ( $arg1 , $arg2 , $arg3 , $vhffs , $path , $template ,  $tmp );
	$vhffs = shift;
	$arg1 = shift;
	$arg2 = shift;
	$arg3 = shift;
	$path = $vhffs->get_config->get_templatedir;

	$tmp = shift;
	
	if( $arg3 )
	{
		$path .= "/" . $arg1 . "/" . $arg2 . "/" . $arg3 . ".tmpl";
	}
	elsif( $arg2 )
	{
		$path .= "/" . $arg1 . "/" . $arg2 . ".tmpl";
	}
	else
	{
		$path .= "/" . $arg1 . ".tmpl";
	}

	$template = new HTML::Template( filename => $path  , die_on_bad_params => 0  );

	return( $template );
}

 
1;
