#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;


use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;

my $panel = new Vhffs::Panel::Main();
if(!$panel)  {
        exit 0;
}
my $cgi = $panel->{'cgi'};

my $vhffs = $panel->{'vhffs'};
my $domain_name = $cgi->param("name");
my $user = $panel->{'user'};

my $dns = new Vhffs::Services::DNS( $vhffs , $domain_name , $user );


my $session = $panel->{'session'};
my $maintemplate = $panel->{'template'};

my $group = $panel->{'group'};
my $projectname = $session->param("project");

my $templatedir = $vhffs->get_config->get_templatedir;
my $subtemplate;
my $thirdtemplate;
my $template;
my $output = "";
my $message;

if( ( ! defined $domain_name ) || ( ! defined $dns ) )
{
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	$message = gettext( "CGI Error!");
	$template->param( MESSAGE => $message );
}
elsif( ( my $retour = $dns->fetch ) < 0 )
{

	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	$message = gettext( "Cannot get informations on this object");
	$template->param( MESSAGE => $message );

}
elsif( ( Vhffs::Acl::what_perm_for_user( $user , $dns , $vhffs ) < Vhffs::Constants::ACL_VIEW ) && ( $user->is_admin != 1 ) )
{
    $template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
    $message = gettext("You're not allowed to do this (ACL rights)");
    $template->param( MESSAGE => $message );
}
elsif( ( $dns->get_status != Vhffs::Constants::ACTIVATED ) && ( $user->is_admin != 1 ) )
{
    
    $template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
    my $message = gettext( "This object is not functionnal yet. Please wait creation or moderation.");
    $template->param( MESSAGE => $message );
}
else
{
	my $cnames = $dns->get_cname_type;
	my $a = $dns->get_a_type;
	my $mx = $dns->get_mx_type;
	my $ns = $dns->get_ns_type;

	$template = new HTML::Template( filename => $templatedir."/dns/prefs.tmpl" );
	$template->param( TITLE => gettext("Admin DNS") );


    $template->param( DOMAIN_NAME => $domain_name );
    $template->param( TEXT_TYPEA => gettext("All A TYPE for you domain name") );
    $template->param( TEXT_TYPEMX => gettext("All MX TYPE for you domain name") );
    $template->param( TEXT_TYPECNAME => gettext("All CNAME for you domain name") );
    $template->param( TEXT_LIST_A => gettext("List all all A reccords") );
    $template->param( TEXT_ADD_A => gettext("Add an A record") );



	#Treat ACL part
    $template->param( TEXT_ACL_ADMIN => gettext( "Admin Rights on this object (ACL)") );
    $template->param( EXPLAIN_ADMIN_ACL => gettext( "You can Manage rights on this service for each user in the VHFFS database. Please read help before manage it.") );
    $template->param( ADMIN_ACL => gettext("Ok, go to ACL admin") );


	#Treat the delete part
	$template->param( TEXT_DELETE_DNS => gettext("Delete this domain name from the VHFFS platform") );
	$template->param( TEXT_BEFORE_DELETE => gettext("This action is non-reversible. All services associated to this project will be DESTROYED.") );
	$template->param( ASK_DELETE_DNS => gettext("Are you SURE you want DELETE this domain ?") );
	$template->param( YES => gettext("Yes I'm sure of what I do") );
	$template->param( NO => gettext("No, I'm not sure, I prefer to keep it.") );
	$template->param( TEXT_DELETE => gettext("Delete") );


	#All templates values for A reccords
    $template->param( TEXT_QUESTION_REDIRECTION => gettext("Must we redirect the DNS on our servers ?") );
    $template->param( TEXT_YES => gettext("Yes") );
    $template->param( TEXT_NO => gettext("No") );
    $template->param( TEXT_ADDIP => gettext("IP") );
    $template->param( TEXT_DOMAINNAME => gettext("Name for reccord") );
    $template->param( TEXT_SUBMIT => gettext("Add !") );


	#All templates for MX reccords
    $template->param( TEXT_LIST_MX => gettext("All MX TYPE for your domain name") );
    $template->param( TEXT_ADD_MX => gettext("Add a MX field to your domain") );
    $template->param( MX_NAME => gettext("Name of your MX") );
    $template->param( MX_PRIORITY => gettext("Priority of your MX") );
    $template->param( TEXT_SUBMIT => gettext("Submit") );


	#Treat CNAME PART
    $template->param( TEXT_LIST_CNAME => gettext("All CNAME TYPE for your domain name") );
    $template->param( TEXT_ADD_CNAME => gettext("Add a CNAME field to your domain") );
    $template->param( TEXT_SUBMIT => gettext("Submit") );
    $template->param( CNAME_DESTINATION => gettext("Destination") );
    $template->param( CNAME_PREFIX => gettext("Subdomain name") );

	#Treat NS part
    $template->param( TEXT_TYPENS => gettext("NS TYPE") );
    $template->param( TEXT_LIST_NS => gettext("All NS TYPE for your domain name") );
    $template->param( TEXT_ADD_NS => gettext("Add a NS field to your domain") );
    $template->param( NS_HOSTNAME_TEXT => gettext("IP/host of your NS") );



    $template->param( TEXT_SUBMIT => gettext("Submit") );


#    $template->param( TEXT_LIST_TYPE_CNAME => gettext("All CNAME for you domain name") );

	$subtemplate = new HTML::Template( filename =>$templatedir. "/dns/list_sub.tmpl" );


	if( defined $a )
	{
		foreach( keys %{$a} )
		{
	          my $thirdtemplate = new HTML::Template( filename => $templatedir."/dns/list_a_sub.tmpl" );
	          $thirdtemplate->param( NOM => $_ );
	          $thirdtemplate->param( IPNOM => $a->{$_}{data} );
	          $thirdtemplate->param( DEL => gettext( "Delete" ) );
	          $thirdtemplate->param( MODIFY => gettext( "Modify" ) );
	          $thirdtemplate->param( DOMAIN => $domain_name );
	          $output .= $thirdtemplate->output;
    	 }
    	$template->param( LIST_A => $output );
	 }
	 else
	 {
    	$template->param( LIST_A => gettext("No A type found" ));
	 }

	if( defined $mx )
	{
		$output = "";
		foreach( keys ( %{$mx} ) )
		{
	            $thirdtemplate = new HTML::Template( filename => $templatedir."/dns/list_mx_sub.tmpl" );
	            $thirdtemplate->param( PRIORITY_VALUE => $_ );
	            $thirdtemplate->param( TEXT_PRIORITY => gettext("Priority: "));
	            $thirdtemplate->param( IP_VALUE => $mx->{$_}{data} );
	          	$thirdtemplate->param( DEL => gettext( "Delete" ) );
				$thirdtemplate->param( MODIFY => gettext( "Modify" ) );
	            $thirdtemplate->param( DOMAIN => $domain_name );
				$output .= $thirdtemplate->output;
	    }
		$template->param( LIST_MX => $output );
	}
	else
	{
		$template->param( LIST_MX => gettext( "No MX reccord for this domain" ));
	}

	if( defined $cnames )
	{
		$output = "";
		foreach( keys ( %{$cnames} ) )
		{
            $thirdtemplate = new HTML::Template( filename => $templatedir."/dns/list_cname_sub.tmpl" );
            $thirdtemplate->param( VALUE_NAME => $_ );
            $thirdtemplate->param( VALUE_DESTINATION => $cnames->{$_}{data} );
          	$thirdtemplate->param( DEL => gettext( "Delete" ) );
			$thirdtemplate->param( MODIFY => gettext( "Modify" ) );
            $thirdtemplate->param( DOMAIN => $domain_name );
		    $output .= $thirdtemplate->output;
    	 }
		$template->param( LIST_CNAME => $output );
	}
	else
	{
		$template->param( LIST_CNAME => gettext( "No CNAME available on this domain") );
	}



	if( defined $ns )
	{
		$output = "";
		foreach( keys ( %{$ns} ) )
		{
            $thirdtemplate = new HTML::Template( filename => $templatedir."/dns/list_ns_sub.tmpl" );
            $thirdtemplate->param( IP => $_ );
          	$thirdtemplate->param( DEL => gettext( "Delete" ) );
            $thirdtemplate->param( DOMAIN => $domain_name );
		    $output .= $thirdtemplate->output;
    	 }
		$template->param( LIST_NS => $output );
	}
	else
	{
		$template->param( LIST_NS => gettext( "No NS available on this domain") );
	}

	if( $user->is_admin == 1 )
	{
            $subtemplate = new HTML::Template( filename => $templatedir."/admin/misc/opart.tmpl" );
			$subtemplate->param( OID => $dns->get_oid );
			$subtemplate->param( OPART_TEXT => gettext("Go to object-part admin") );
			$subtemplate->param( OPART_TITLE => gettext("Object part") );
			$template->param( OPART => $subtemplate->output );
	}
}

display Vhffs::Panel::Main($panel, $template->output);
