#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use GD;
use GD::Text::Wrap;


use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;

my $panel = new Vhffs::Panel::Main();

my $vhffs = $panel->{'vhffs'};
my $session = $panel->{'session'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};
my $cgi = $panel->{'cgi'};
my $groupname = $cgi->param('group');

my $templatedir = $vhffs->get_config->get_templatedir;
my $template;
my $subtemplate;
my $group = new Vhffs::Group( $vhffs , $groupname , '401' );

my $status;
my $quota;
my $quota_used;
my $black;
my $blue;
my $white;
my $red;
my $green;
my $gd;
my $wp;
my $moy;

if( ! $panel)  {
        exit 0;
}

$status = 0;

if( ( ! defined $group ) || ( $group->fetch < 0 ) )
{
	$gd = GD::Image->new(70,100);
	$white = $gd->colorAllocate(255,255,255);
	$black = $gd->colorAllocate(  0,  0,  0);
	$blue  = $gd->colorAllocate(127,127,255);

	$wp = GD::Text::Wrap->new($gd,
		width       => 70,
		line_space  => 0,
		color       => $black,
		text        => "You have not enough right",
	);
	$wp->set_font(gdLargeFont, 14);
	$wp->set(align => 'center');  
	$wp->draw(0,5);
	$wp->set(para_space => 10, preserve_nl => 0);
}
elsif( ( Vhffs::Acl::what_perm_for_user( $user , $group , $vhffs ) < Vhffs::Constants::ACL_VIEW ) && ( $user->is_admin != 1 ) )
{
	$gd = GD::Image->new(70,100);
	$white = $gd->colorAllocate(255,255,255);
	$black = $gd->colorAllocate(  0,  0,  0);
	$blue  = $gd->colorAllocate(127,127,255);

	$wp = GD::Text::Wrap->new($gd,
		width       => 70,
		line_space  => 0,
		color       => $black,
		text        => "You have not enough right",
	);
	$wp->set_font(gdLargeFont, 14);
	$wp->set(align => 'center');  
	$wp->draw(0,5);
	$wp->set(para_space => 10, preserve_nl => 0);
}

elsif( $group->get_status != Vhffs::Constants::ACTIVATED )
{
	$gd = GD::Image->new(70,100);
	$white = $gd->colorAllocate(255,255,255);
	$black = $gd->colorAllocate(  0,  0,  0);
	$blue  = $gd->colorAllocate(127,127,255);

	$wp = GD::Text::Wrap->new($gd,
		width       => 70,
		line_space  => 0,
		color       => $black,
		text        => "Group not activated",
	);
	$wp->set_font(gdLargeFont, 14);
	$wp->set(align => 'center');  
	$wp->draw(0,5);
}
else
{
	$quota = $group->get_quota;
	$quota_used = $group->get_quota_used;
	$moy = ( ( $quota_used / $quota ) * 100 );


	$gd = GD::Image->new(301,11);
	$white = $gd->colorAllocate(255,255,255);
	$black = $gd->colorAllocate(  0,  0,  0);
	$blue  = $gd->colorAllocate(127,127,255);
	$red  = $gd->colorAllocate( 207 , 9 , 9 );
	$gd->rectangle(0,0,300,10,$black);
	$gd->rectangle(1,1, 3 * $moy,9,$red);
	$gd->fill($moy - 1 , 8 ,$red);
	
}

print CGI->header( -type=>"image/png" );
binmode STDOUT;
print STDOUT $gd->png();
close STDOUT;
exit 0;
