#!/usr/bin/perl -w 
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;
use Crypt::PasswdMD5;
use Vhffs::Misc::Salt;

use Vhffs::User;
use Vhffs::Main;
use Vhffs::Panel::Main;

# nettoyage de la session precedente
my $oldsid = CGI->cookie("session");
if($oldsid) {
	my $oldsession = new CGI::Session(undef, $oldsid, {Directory=>'/tmp'});
	$oldsession->delete();
}

# Init the Vhffs Main System
my $vhffs = init Vhffs::Main;

my $templatedir = $vhffs->get_config->get_templatedir;

my $cookie = Vhffs::Panel::Main::cookie_lang( $vhffs );

# recuperation des donnees des champs du form de login
my $current_cgi = new CGI;
my $username = $current_cgi->param("username");
my $password = $current_cgi->param("password");
my $user = new Vhffs::User( $vhffs, $username, 401 );

my $auth = 0;

my $template;


#If platform is closed, the user cannot log in
if( $vhffs->get_config->get_panel_open == 0 )
{
    $template = new HTML::Template( filename => $templatedir."/main/close.tmpl" );
    $template->param( TITLE         => gettext("Platform temporary closed") );
    $template->param( TEXT_CLOSE    => gettext("Platform temporary closed.") );
    $template->param( TEXT_EXPLAIN  => gettext("This platform is temporary closed. Administrators are performing some maintenances tasks. Please come back in a few minutes to log in.") );
	display_light Vhffs::Panel::Main( $vhffs , $template );
	exit 0;
}

if( ( ! defined( $username ) ) || ( ! defined ( $password ) ) || ( ! defined $user ) )
{

	$template = new HTML::Template( filename => $templatedir."/main/login_failed.tmpl" );
	$template->param( TITLE => gettext("VHFFS Login failed") );
	$template->param( TEXT_LOGINFAILED => gettext("Login failed !") );
	$template->param( TEXT_LOGIN => gettext("Login") );

	display_light Vhffs::Panel::Main( $vhffs , $template );
}
else
{


	my $ret = $user->fetch;
	if ( $ret >= 0 )  {
		$auth=1 if ( $user->check_password( $password ) && ( $user->get_status == Vhffs::Constants::ACTIVATED ) )
	}

	if( $auth == 1 )
	{
		my $session = new CGI::Session("driver:File", undef, {Directory=>'/tmp'});
		$session->expires("+1h");
		$session->param("username", $user->get_username);
		$session->param("uid", $user->get_uid);
	
		my $sid = $session->id();
		my $cookie = CGI->cookie(session => $sid);
	
		$template = new HTML::Template( filename => $templatedir."/main/login_ok.tmpl" );
		$template->param( TITLE => gettext("VHFFS Login OK") );
		$template->param( TEXT_PLEASEWAIT => gettext("Login OK, please wait...") );
		$template->param( TEXT_PANEL => gettext("Panel Access") );

		display_light Vhffs::Panel::Main( $vhffs , $template , $cookie);
	}
	else  
	{
	
		$template = new HTML::Template( filename => $templatedir."/main/login_failed.tmpl" );
		$template->param( TITLE => gettext("VHFFS Login failed") );
		$template->param( TEXT_LOGINFAILED => gettext("Login failed !") );
		$template->param( TEXT_LOGIN => gettext("Login") );
	
		display_light Vhffs::Panel::Main( $vhffs , $template );
	}
}
