#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Acl;
use Vhffs::Constants;
use Vhffs::Panel::Main;
use Vhffs::Functions;
use Vhffs::Services::LargeFile;

my $vhffs = init Vhffs::Main;
my $cookie = Vhffs::Panel::Main::cookie_lang( $vhffs );
my $template;
my $subtemplate;
my $templatedir = $vhffs->get_config->get_templatedir;
my $cgi = new CGI;
my $repos;
my $files;
my $filename;
my $groupname;
my $group;
my $file;
my $message;
my $mirrors;
my $mirror;
my $temp;

$filename = $cgi->param("filename");
$groupname = $cgi->param("groupname");

$groupname = Vhffs::Functions::check_arg( $groupname );
$filename = Vhffs::Functions::check_arg( $filename );



if( ( ! defined $groupname ) || ( ! defined $filename ) )
{
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	$message = gettext( "CGI ERROR!");
	$message .= $filename . $groupname;
	$template->param( MESSAGE => $message );
}
elsif( $vhffs->get_config->use_largefile != 1 )
{
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	$message = gettext( "Does not support largefile");
	$template->param( MESSAGE => $message );
}
elsif( ( ! defined ($group= new Vhffs::Group( $vhffs , $groupname , '401' ) ) ) || ( $group->fetch < 0 ))
{

	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	$message = gettext( "No such group");
	$template->param( MESSAGE => $message );

}
elsif( ( ! defined ( $file = new Vhffs::Services::LargeFile( $vhffs , $filename , '401' , $group ) ) ) || ( $file->fetch < 0 ))
{

	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	$message = gettext( "Invalid file");
	$template->param( MESSAGE => $message );

}
else
{
	$template = new HTML::Template( filename => $templatedir."/public/largefile.tmpl" );
	$template->param( THEME => Vhffs::Panel::Main::get_theme( $vhffs ) );
	$template->param( TEXT_TITLE => sprintf( gettext("Download %s") , $file->get_filename ) );
	$template->param( TEXT_TYPE => gettext("File type") );
	$template->param( TEXT_SIZE => gettext("Size") );
	$template->param( TEXT_HASH => gettext("Hash") );
	$template->param( TEXT_LICENCE => gettext("License of this file") );

	$template->param( VALUE_TYPE => gettext("File type") );
	$template->param( VALUE_SIZE => gettext("Size") );

	if( $file->get_hash eq "" )
	{
		$template->param( VALUE_HASH => gettext("No hash") );
	}
	else
	{
		$template->param( VALUE_HASH => $file->get_hash );
	}
	$template->param( VALUE_LICENCE => $file->get_licence );
	$template->param( VALUE_SIZE => $file->get_size );
	$template->param( VALUE_TYPE => $file->get_type );

	$template->param( TEXT_MIRRORS => gettext( "Mirrors" ));

	$mirrors = $vhffs->get_config->largefile_mirrors;

	if( ! defined( $mirrors ) )
	{
		$template->param( VALUE_MIRRORS => gettext( "No server" ));
	}
	else
	{
		$temp = "";
		foreach $mirror ( @{$mirrors} )
		{
			$subtemplate = new HTML::Template( filename => $templatedir."/public/misc/largefile-dl.tmpl" );
			$subtemplate->param( DOWNLOAD => gettext( "Download" ) );
			$subtemplate->param( GROUPNAME => $file->get_group->get_groupname );
			$subtemplate->param( URL => $mirror->{'url'} );
			$subtemplate->param( LOGO => $mirror->{'logo'} );
			$subtemplate->param( MIRRORNAME => $mirror->{'name'} );
			$subtemplate->param( LINK => $mirror->{'link'} );
			$subtemplate->param( COUNTRY => $mirror->{'country'} );
			$subtemplate->param( FILENAME => $file->get_filename );
			$subtemplate->param( THEME => Vhffs::Panel::Main::get_theme( $vhffs ) );
		
			$temp .= $subtemplate->output;
		}
		$template->param( VALUE_MIRRORS => $temp );

	}

}
print "Content-Type: text/html; charset=utf-8\n\n" . $template->output;


